COTEMIG - Faculdade de TI e Colégio de Informática
Description: O COTEMIG é referência e tradição no ensino da informática e da tecnologia da informação (TI) oferecendo cursos técnicos e superiores de qualidade

# Cotemig

## Comemoração

## Laboratórios

Conheça os laboratórios do COTEMIG

## Tecnofeira

Fique por dentro

## Acontece no COTEMIG

## Trabalho de construção dos sólidos geométricos

O trabalho de construção dos sólidos geométricos realizados com as turmas da terceira série em ambas as unidades teve...

outras notícias

- ## COTEMIG apresenta nova coleção de uniformes em diversas cores e modelos

  [13 de novembro de 2015] O Colégio COTEMIG realizou, nos dias 5 e 6/11, mais uma edição do Desfile de Uniformes, apresentando a coleção...

- ## COTEMIG apoia I Workshop de Desenvolvimento de Apps Xamarin do Brasil

  [03 de novembro de 2015] Em outubro de 2015 aconteceu o Workshop de Desenvolvimento de aplicativos móveis com C# e Xamarin do Brasil com...

COTEMIG no seu e-mail

Cadastre-se e receba em seu e-mail tudo que acontece no COTEMIG.

Escolha qual o assunto que você deseja receber notícias:

Colégio Faculdade Tecnofeira

Últimas da Rede

@ColCotemig

## Twitter: colcotemig

- Seis grupos da #Tecnofeira2015 foram escolhidos pelo MGTi e três serão escolhidos para ganhar consultoria. https://t.co/A98ZG7nEER about 15 hours ago from TweetDeck Reply Retweet Favorite
- RT @fumsoft: O MGTI, representado pela Assespro Minas Gerais e pela Fumsoft avaliou os projetos da Tecnofeira e irá premiar... https://t.co… about 15 hours ago from TweetDeck Reply Retweet Favorite

@FacCotemig

## Twitter: faccotemig

- Como empreender na era da Internet das Coisas: https://t.co/i9FwRpDx21 about 7 hours ago from TweetDeck Reply Retweet Favorite
- 90% dos CIOs se sentem ignorados em relação às decisões de TI:https://t.co/eiNohNhqyN 02/12/2015 - 04:00:03 from TweetDeck Reply Retweet Favorite
- 36 pontos para analisar sua maturidade de transformação digital: https://t.co/ceyPhFDKkI 01/12/2015 - 12:00:07 from TweetDeck Reply Retweet Favorite

Redes Sociais

Colégio

Acompanhe o Colégio nas redes sociais

Faculdade

Acompanhe a Faculdade nas redes sociais

- ## COTEMIG Barroca

  (31) 3313.6500

  Rua Santa Cruz, 546
  Bairro Barroca
  Belo Horizonte MG
  CEP: 30.431-228

  como chegar

- ## COTEMIG Floresta

  (31) 3236.8400

  Rua Itajubá, 223
  Bairro Floresta
  Belo Horizonte MG
  CEP: 30.150-380

  como chegar

- ## Faculdade COTEMIG

  (31) 3371.3051

  Rua Santa Cruz, 546
  Bairro Barroca
  Belo Horizonte MG
  CEP: 30.431-228

  como chegar

- ## Escritório Central

  (31) 3313.6501

  Rua Litargírio, 25
  Bairro Grajaú
  Belo Horizonte MG
  CEP: 30.431-232

  como chegar

Área restrita

Usuário: Senha:

Esqueceu sua senha?